@@ -45,20 +45,15 @@
 /* ========================================================================= */
 
 LeakFinderPtr::LeakFinderPtr(void *p , const char *f, const int l) :
-        file(f),
-        line(l),
-        when(squid_curtime)
+        file(f), line(l), when(squid_curtime)
 {
-    // XXX: these bits should be done by hash_link()
     key = p;
     next = NULL;
 }
 
 /* ========================================================================= */
 
-LeakFinder::LeakFinder() :
-        count(0),
-        last_dump(0)
+LeakFinder::LeakFinder()
 {
     debugs(45, 3, "LeakFinder constructed");
     table = hash_create(cmp, 1 << 8, hash);
