@@ -70,6 +70,7 @@
 #include "Icmp4.h"
 #include "Icmp6.h"
 #include "IcmpPinger.h"
+#include "ip/tools.h"
 
 #if _SQUID_MSWIN_
 
@@ -147,6 +148,9 @@ main(int argc, char *argv[])
 
     getCurrentTime();
 
+    // determine IPv4 or IPv6 capabilities before using sockets.
+    Ip::ProbeTransport();
+
     _db_init(NULL, debug_args);
 
     debugs(42, DBG_CRITICAL, "pinger: Initialising ICMP pinger ...");
